@@ -35,7 +35,15 @@ except:
 class IMdata:
     def __init__(self):
         self.havedata = False
-
+        self.data=np.zeros(1)
+        self.t_obs=np.zeros(1)
+        self.freq=np.zeros(1)
+        self.xx=np.zeros(1)
+        self.yy=np.zeros(1)
+        self.data_xy_calib=np.zeros(1)
+        self.beamArea=np.zeros(1)
+        self.fname=''
+        
     def load_fits(self,fname):
         if len(fname)>0:
             self.havedata = True
